import { SemVer } from "semver";
import { Schema, PackageFile } from "./main";
export declare type DPMRecordValue = number | string | boolean | null;
export declare type DPMRecord = Record<string, DPMRecordValue>;
export declare type DPMConfiguration = Record<string, number | string | boolean | null>;
export declare enum Compability {
    Identical = 0,
    MinorChange = 1,
    CompatibleChange = 2,
    BreakingChange = 3
}
export declare enum DifferenceType {
    REMOVE_SCHEMA = "REMOVE_SCHEMA",
    ADD_SCHEMA = "ADD_SCHEMA",
    CHANGE_PACKAGE_DISPLAY_NAME = "CHANGE_PACKAGE_DISPLAY_NAME",
    CHANGE_PACKAGE_DESCRIPTION = "CHANGE_PACKAGE_DESCRIPTION",
    CHANGE_SOURCE = "CHANGE_SOURCE",
    CHANGE_PARSER = "CHANGE_PARSER",
    ADD_PROPERTY = "ADD_PROPERTY",
    REMOVE_PROPERTY = "REMOVE_PROPERTY",
    CHANGE_PROPERTY_TYPE = "CHANGE_PROPERTY_TYPE",
    CHANGE_PROPERTY_FORMAT = "CHANGE_PROPERTY_FORMAT",
    CHANGE_PROPERTY_DESCRIPTION = "CHANGE_PROPERTY_DESCRIPTION",
    CHANGE_GENERATED_BY = "CHANGE_GENERATED_BY",
    CHANGE_UPDATED_DATE = "CHANGE_UPDATED_DATE",
    CHANGE_VERSION = "CHANGE_VERSION"
}
export interface Difference {
    type: DifferenceType;
    pointer: string;
}
export interface Comparison {
    compatibility: Compability;
    differences: Difference[];
}
export declare function leastCompatible(a: Compability, b: Compability): Compability;
export declare function comparePackages(packageA: PackageFile, packageB: PackageFile): Difference[];
export declare function compareSchemas(priorSchemas: Schema[], newSchemas: Schema[]): Difference[];
export declare function compareSchema(priorSchema: Schema, newSchema: Schema, pointer?: string): Difference[];
export declare function compareConfigObjects(priorObject?: DPMConfiguration | null, newObject?: DPMConfiguration | null): boolean;
export declare function diffCompatibility(diffs: Difference[]): Compability;
export declare function nextVersion(currentVersion: SemVer, diffCompatibility: Compability): SemVer;
export declare function compatibilityToString(compatibility: Compability): string;
export declare function validateCatalogSlug(slug: string | undefined): boolean;
export declare function validatePackageSlug(slug: string | undefined): boolean;
export declare function parsePackageFileJSON(packageFileString: string): PackageFile;
